From eacebbccebc50e5a18c07c496e2ddfaabfabf6d3 Mon Sep 17 00:00:00 2001
From: Ruben Young On <r.d.youngon@student.tudelft.nl>
Date: Fri, 17 May 2019 13:59:38 +0200
Subject: [PATCH] Added more comments on how to pregrade

---
 zesje/pregrader.py | 24 ++++++++++++++++++++----
 1 file changed, 20 insertions(+), 4 deletions(-)

diff --git a/zesje/pregrader.py b/zesje/pregrader.py
index 07627617..6bc1845f 100644
--- a/zesje/pregrader.py
+++ b/zesje/pregrader.py
@@ -4,8 +4,24 @@ from zesje.images import guess_dpi
 import zesje.database
 
 # 1 - get image
 # 2 - get database coordinates of all mc_options
 # 3 - resolution / dpi
 # 4 - get corner marker keypoints
 # 5 - determine blank pdf corner markers vs submission corner markers
 # 6 - transform submission image
+# 7 - determine checkbox locations
+# 8 - get box location and check if it is filled
+# 8.5 - check if feedback option exists
+# 9 - connect to feedback option
+
+# coupled feedback cannot be deleted
+
+
+def pregrade(exam_id):
+    # Get exam pages
+
+    pass
+
+
+def _locate_checkbox():
+    pass
@@ -4,8 +4,24 @@ from zesje.images import guess_dpi
 
 # 1 - get image
-# 2 - get database coordinates of all mc_options
-# 3 - resolution / dpi
-# 4 - get corner marker keypoints
-# 5 - determine blank pdf corner markers vs submission corner markers
+# 2 - get database coordinates of all mc_options in exam
+# 3 - resolution / dpi to convert points to inches to pixels
+# 4 - get corner marker keypoints per page
+# 5 - optional? determine blank pdf corner markers vs submission corner markers
 # 6 - transform submission image
-- 
GitLab